package com.hibernate.util;

import java.sql.CallableStatement;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.Random;

import org.hibernate.Session;
import org.hibernate.cfg.Configuration;
import org.hibernate.jdbc.Work;

public class AppMain {

	public static void main(String[] args) {		
		// Creating the configuration instance & passing the hibernate configuration file.
		Configuration config = new Configuration();
		config.configure("hibernate.cfg.xml");

		// Hibernate session object to start the db transaction.
		Session s = config.buildSessionFactory().openSession();

		// Opening the transaction.
		s.beginTransaction();

		// Inserting the data to the database using the Hibernate's Work interface.
		// Hibernate's doWork() method performs the CRUD operations in the database!
		s.doWork(new Work(){
			@Override
			public void execute(Connection conn) throws SQLException {
				int count = 0;
				CallableStatement stmt = null;
				try {
					String sqlstring = "{call addEmployee(?, ?, ?, ?)}";
					stmt = conn.prepareCall(sqlstring);

					for(int i=1, j=100; i<6; i++, j=j+10) {
						// The key parameters must match the input argument names of the stored procedure.
						stmt.setString("name", "Employee"+i);
						stmt.setString("designation", "Manager"+j);
						stmt.setString("department", "Technology");
						stmt.setInt("salary", new Random().nextInt(100000 - 50000) + 50000);

						count = count + stmt.executeUpdate();
					}
					System.out.println(count + " rows inserted.");
				} finally {
					stmt.close();
				}
			}
		});

		// Commiting the employee data to the database.
		s.getTransaction().commit();

		// Closing the session object.
		s.close();
	}
}